django-taggit wrapper for Ella CMS
========================================

Adds tagging functionality for Ella CMS by providing wrapper over django-taggit.

Recommended to use in prior of to ella-tagging, since this is faster
implementation with more possibilities.